Index: trunk/Assembly_Library/Src/Menu/Dialog/DialogWord.asm
===================================================================
--- trunk/Assembly_Library/Src/Menu/Dialog/DialogWord.asm	(revision 289)
+++ trunk/Assembly_Library/Src/Menu/Dialog/DialogWord.asm	(revision 293)
@@ -85,5 +85,5 @@
 GetWordFromUser:
 	lds		si, [bp+DIALOG.fpDialogIO]
-	eMOVZX	bx, BYTE [si+WORD_DIALOG_IO.bNumericBase]
+	eMOVZX	bx, [si+WORD_DIALOG_IO.bNumericBase]
 ALIGN JUMP_ALIGN
 .GetUserInputIntilValidOrCancelled:
Index: trunk/Assembly_Library/Src/Menu/MenuBorders.asm
===================================================================
--- trunk/Assembly_Library/Src/Menu/MenuBorders.asm	(revision 289)
+++ trunk/Assembly_Library/Src/Menu/MenuBorders.asm	(revision 293)
@@ -118,5 +118,5 @@
 ALIGN JUMP_ALIGN
 MenuBorders_GetNumberOfMiddleCharactersToDX:
-	eMOVZX	dx, BYTE [bp+MENUINIT.bWidth]
+	eMOVZX	dx, [bp+MENUINIT.bWidth]
 	sub		dx, BYTE MENU_HORIZONTAL_BORDER_LINES
 	ret
@@ -136,5 +136,5 @@
 RefreshTitleBorders:
 	call	DrawTopBorderLine
-	eMOVZX	cx, BYTE [bp+MENUINIT.bTitleLines]
+	eMOVZX	cx, [bp+MENUINIT.bTitleLines]
 	jmp		SHORT DrawTextBorderLinesByCXtimes
 
@@ -152,5 +152,5 @@
 RefreshInformationBorders:
 	call	DrawSeparationBorderLine
-	eMOVZX	cx, BYTE [bp+MENUINIT.bInfoLines]
+	eMOVZX	cx, [bp+MENUINIT.bInfoLines]
 	jmp		SHORT DrawTextBorderLinesByCXtimes
 
Index: trunk/Assembly_Library/Src/Menu/MenuCharOut.asm
===================================================================
--- trunk/Assembly_Library/Src/Menu/MenuCharOut.asm	(revision 289)
+++ trunk/Assembly_Library/Src/Menu/MenuCharOut.asm	(revision 293)
@@ -61,5 +61,5 @@
 	mov		al, CR
 	call	DisplayCharOut_BiosTeletypeOutput
-	eMOVZX	ax, BYTE [VIDEO_BDA.displayContext+DISPLAY_CONTEXT.wCharOutParam]
+	eMOVZX	ax, [VIDEO_BDA.displayContext+DISPLAY_CONTEXT.wCharOutParam]
 	add		di, ax
 ReturnSinceNoNeedToStartLineWithControlCharacter:
Index: trunk/Assembly_Library/Src/Menu/MenuLocation.asm
===================================================================
--- trunk/Assembly_Library/Src/Menu/MenuLocation.asm	(revision 289)
+++ trunk/Assembly_Library/Src/Menu/MenuLocation.asm	(revision 293)
@@ -114,5 +114,5 @@
 ALIGN JUMP_ALIGN
 MenuLocation_GetMaxTextLineLengthToAX:
-	eMOVZX	ax, BYTE [bp+MENUINIT.bWidth]
+	eMOVZX	ax, [bp+MENUINIT.bWidth]
 	sub		ax, BYTE MENU_HORIZONTAL_BORDER_LINES + MENU_TEXT_COLUMN_OFFSET
 	ret
Index: trunk/Assembly_Library/Src/Menu/MenuScrollbars.asm
===================================================================
--- trunk/Assembly_Library/Src/Menu/MenuScrollbars.asm	(revision 289)
+++ trunk/Assembly_Library/Src/Menu/MenuScrollbars.asm	(revision 293)
@@ -245,5 +245,5 @@
 ALIGN JUMP_ALIGN
 MenuScrollbars_GetMaxVisibleItemsOnPageToCX:
-	eMOVZX	cx, BYTE [bp+MENUINIT.bHeight]
+	eMOVZX	cx, [bp+MENUINIT.bHeight]
 	sub		cl, [bp+MENUINIT.bTitleLines]
 	sub		cl, [bp+MENUINIT.bInfoLines]

Index: trunk/Assembly_Library/Src/Menu/Dialog/DialogFile.asm
===================================================================
--- trunk/Assembly_Library/Src/Menu/Dialog/DialogFile.asm	(revision 289)
+++ trunk/Assembly_Library/Src/Menu/Dialog/DialogFile.asm	(revision 293)
@@ -173,5 +173,5 @@
 
 	lds		si, [bp+DIALOG.fpDialogIO]
-	eMOVZX	cx, BYTE [si+FILE_DIALOG_IO.bFileAttributes]
+	eMOVZX	cx, [si+FILE_DIALOG_IO.bFileAttributes]
 	lds		si, [si+FILE_DIALOG_IO.fpFileFilterString]
 	call	Directory_UpdateDTAForFirstMatchForDSSIwithAttributesInCX
@@ -518,5 +518,5 @@
 	xor		ax, ax
 	stosb						; Terminate with NULL
-	jmp		SHORT CloseFileDialogAfterSuccessfullSelection
+	jmp		SHORT CloseFileDialogAfterSuccessfulSelection
 
 ;--------------------------------------------------------------------
@@ -617,5 +617,5 @@
 	test	al, al		; User cancellation?
 	jnz		SHORT ReturnWithoutHandlingKeystroke
-	jmp		CloseFileDialogAfterSuccessfullSelection
+	jmp		CloseFileDialogAfterSuccessfulSelection
 
 ALIGN JUMP_ALIGN
@@ -646,8 +646,8 @@
 	test	al, FLG_FILEDIALOG_DIRECTORY
 	jz		SHORT ReturnWithoutHandlingKeystroke
-	; Fall to CloseFileDialogAfterSuccessfullSelection
-
-;--------------------------------------------------------------------
-; CloseFileDialogAfterSuccessfullSelection
+	; Fall to CloseFileDialogAfterSuccessfulSelection
+
+;--------------------------------------------------------------------
+; CloseFileDialogAfterSuccessfulSelection
 ;	Parameters:
 ;		SS:BP:	Ptr to DIALOG
@@ -658,5 +658,5 @@
 ;--------------------------------------------------------------------
 ALIGN JUMP_ALIGN
-CloseFileDialogAfterSuccessfullSelection:
+CloseFileDialogAfterSuccessfulSelection:
 	lds		di, [bp+DIALOG.fpDialogIO]
 	mov		BYTE [di+FILE_DIALOG_IO.bUserCancellation], FALSE